Coverage report

# Coverage report: 59%

Hot-keys on this page

n s m x b p c change column sorting

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
Total | 633 | 220 | 0 | 338 | 86 | 59%
plugins/module_utils/network/meraki/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
plugins/module_utils/network/meraki/meraki.py | 301 | 115 | 0 | 152 | 35 | 55%
plugins/modules/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
plugins/modules/meraki_device.py | 174 | 23 | 0 | 86 | 23 | 81%
plugins/modules/meraki_network.py | 158 | 82 | 0 | 100 | 28 | 42%

No items found using the specified filter.